@@ -216,7 +216,7 @@ from ae.gui_app import (
     FLOW_KEY_SEP, flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs, MainAppBase)
 
 
-__version__ = '0.2.42'
+__version__ = '0.2.43'
 
 
 register_package_translations()
@@ -662,15 +662,14 @@ class TourBase:
         widgets = list()
         page_id = self.page_ids[self.page_idx]
         if page_id in self.pages_explained_matchers:
-            matcher = self.pages_explained_matchers[page_id]
-            matchers = matcher if isinstance(matcher, (list, tuple)) else (matcher, )
-            for matcher in matchers:
+            matchers = self.pages_explained_matchers[page_id]
+            for matcher in matchers if isinstance(matchers, (list, tuple)) else (matchers, ):
                 if isinstance(matcher, str):
                     match_str = matcher
                     matcher = try_eval(match_str, ignored_exceptions=(Exception, ),     # NameError, SyntaxError, ...
                                        glo_vars=main_app.global_variables(layout=layout, tour=self))
                     if not callable(matcher):
-                        matcher = lambda widget: widget_page_id(widget) == match_str    # noqa: E731
+                        matcher = lambda _w: widget_page_id(_w) == match_str            # noqa: E731
                 else:
                     match_str = ""
                 wid = main_app.find_widget(matcher)
@@ -678,6 +677,8 @@ class TourBase:
                     wid = getattr(main_app.framework_root, 'ids', dict()).get(match_str)
                 if wid:
                     widgets.append(wid)
+                else:
+                    main_app.vpo(f"{self.__class__.__name__}/{page_id}: no widget from matcher {match_str or matcher}")
             if len(widgets) > 1:
                 exp_wid = layout.explained_placeholder
                 exp_wid.x, exp_wid.y, exp_wid.width, exp_wid.height = main_app.widgets_enclosing_rectangle(widgets)
@@ -789,30 +790,32 @@ class TourDropdownFromButton(TourBase):
     determine_page_ids = '_v_'
 
     def setup_app_flow(self):
-        """ prevent opening of sub-menus and close of dropdown if dropdown child would open another dropdown. """
+        """ manage the opening state of the dropdown (open dropdown, only close it if opening button get explained). """
         super().setup_app_flow()
-        if self.last_page_idx == 0 and self.page_idx == 1:
-            last_page_id = self.page_ids[self.last_page_idx]
-            if flow_action(last_page_id) == 'open':
-                self.main_app.change_flow(last_page_id, **update_tap_kwargs(self.layout.explained_widget))
+        page_id = self.page_ids[0]
+        assert flow_action(page_id) == 'open', f"TourDropdownFromButton 1st page '{page_id}' missing 'open' flow action"
+        lpi = self.last_page_idx
+        pgi = self.page_idx
+        if lpi is None and pgi == 0 or lpi == 0 and pgi == 1 and not self.top_popup:
+            main_app = self.main_app
+            main_app.change_flow(page_id, **update_tap_kwargs(main_app.widget_by_page_id(page_id)))
 
-        elif self.last_page_idx == 1 and self.page_idx == 0 \
-                and self.top_popup and flow_action(self.page_ids[self.page_idx]) == 'open':
+        elif lpi == 1 and pgi == 0 and self.top_popup:
             self.top_popup.close()
 
-    def update_page_ids(self):
-        """ prepare all tour pages - first page is explaining opening dropdown button. """
-        super().update_page_ids()
+    def setup_layout(self):
+        """ prepare layout for all tour pages - first page explains opening dropdown button. """
+        super().setup_layout()
         page_ids = self.page_ids
-        if self.page_idx == 1 and page_ids[-1] == TourDropdownFromButton.determine_page_ids:
+        if page_ids[-1] == TourDropdownFromButton.determine_page_ids:
             main_app = self.main_app
             if not self.top_popup:
-                main_app.po("TourDropDownFromButton.update_page_ids: dropdown not opened")
+                main_app.po("TourDropDownFromButton.setup_layout: dropdown not opened")
                 return
 
             children = main_app.widget_tourable_children_page_ids(self.top_popup)
             if not children:
-                main_app.po(f"TourDropDownFromButton.update_page_ids missing tour-able child in {self.top_popup}")
+                main_app.po(f"TourDropDownFromButton.setup_layout missing tour-able child in {self.top_popup}")
                 return
 
             page_ids.remove(TourDropdownFromButton.determine_page_ids)
@@ -868,12 +871,11 @@ class OnboardingTour(TourBase):
         super().teardown_app_flow()
 
     def update_page_ids(self):
-        """ overridden to remove page (only showing once). """
+        """ overridden to remove 2nd-/well-done-page (only showing once on next-page-jump from 1st-/welcome-page). """
         super().update_page_ids()
         if 'page_switching' in self.page_ids and self.last_page_id:  # last page id not in (None=tour-start,''=1st page)
-            # remove page_switching if not at onboarding startup or after switch from first page to the next one
             self.page_ids.remove('page_switching')
-            if self.page_idx:
+            if self.page_idx:   # correct idx if not back from removed page: self.page_idx == 0; self.last_page_idx == 1
                 self.last_page_idx -= 1
                 self.page_idx -= 1
 
@@ -1188,11 +1190,8 @@ class HelpAppBase(MainAppBase, ABC):
         tourable_children = list()
         for wid in self.widget_children(parent_widget, only_visible=True):
             page_id = widget_page_id(wid)
-            if page_id:
+            if not page_id:
+                tourable_children.extend(self.widget_tourable_children_page_ids(wid))
+            elif page_id not in tourable_children:
                 tourable_children.append(page_id)
-            else:
-                for sub_wid in self.widget_children(wid, only_visible=True):
-                    page_id = widget_page_id(sub_wid)
-                    if page_id and page_id not in tourable_children:
-                        tourable_children.append(page_id)
         return tourable_children
